//--------------------------------------------------------------------
// UTCN, Departamentul de Calculatoare
// Sisteme de intrare/iesire si echipamente periferice
//--------------------------------------------------------------------
// http://users.utcluj.ro/~baruch/ro/pages/cursuri/sisteme-de-intrareiesire/laborator.php
//--------------------------------------------------------------------
// Fisier:		SMBus.h
// Modificat:	22.03.2021
//--------------------------------------------------------------------
// Definitii pentru controlerul SMBus
//--------------------------------------------------------------------

#ifndef _SMBUS_H  
#define _SMBUS_H  

#ifndef _PCI_H
#define PCI_CONFIG_ADR		0x0CF8		// Port de adresa pentru accesul in spatiul de configuratie
#define PCI_CONFIG_DATA		0x0CFC		// Port de date pentru accesul in spatiul de configuratie
#endif

// Structura pentru registrele de configuratie PCI/PCIe
typedef struct tSMBUS_CFG {
	WORD		VID;					// 0x00 Vendor ID
	WORD		DID;					// 0x02 Device ID
	WORD		PCICMD;					// 0x04 PCI Command
	WORD		PCISTS;					// 0x06 PCI Status
	BYTE		RID;					// 0x08 Revision ID
	BYTE		PI;						// 0x09 Programming Interface
	BYTE		SCC;					// 0x0A Sub Class Code
	BYTE		BCC;					// 0x0B Base Class Code
	DWORD		Res0;					// 0x0C-0x0F Reserved
	DWORD		SMBMBAR0;				// 0x10 Memory Base Address Register 0 (31..0)
	DWORD		SMBMBAR1;				// 0x14 Memory Base Address Register 1 (63..32)
	DWORD		Res1[2];				// 0x18-0x1F Reserved
	DWORD		SMB_BASE;				// 0x20 SMBus Base Address
	DWORD		Res2[2];				// 0x24-0x2B Reserved
	WORD		SVID;					// 0x2C Subsystem Vendor ID
	WORD		SID;					// 0x2E Subsysem ID
	DWORD		Res3[3];				// 0x30-0x3B Reserved
	BYTE		INT_LN;					// 0x3C Interrupt Line
	BYTE		INT_PN;					// 0x3D Interrupt Pin
	BYTE		Res4[2];				// 0x3E-0x3F Reserved
	BYTE		HOSTC;					// 0x40 Host Configuration
} SMBUS_CFG, *PSMBUS_CFG;

// Structura pentru registrele controlerului SMBus mapate in memorie
typedef volatile struct tSMBUS_REG {
	BYTE		HST_STS;				// 0x00 Host Status
	BYTE		Res0;					// 0x01 Reserved
	BYTE		HST_CNT;				// 0x02 Host Control
	BYTE		HST_CMD;				// 0x03 Host Command
	BYTE		XMIT_SLVA;				// 0x04 Transmit Slave Address
	BYTE		HST_D0;					// 0x05 Host Data 0
	BYTE		HST_D1;					// 0x06 Host Data 1
	BYTE		HOST_BLOCK_dB;			// 0x07 Host Block Data Byte
	BYTE		PEC;					// 0x08 Packet Error Check (PEC)
	BYTE		RCV_SLVA;				// 0x09 Receive Slave Address
	WORD		SLV_DATA;				// 0x0A Receive Slave Data
	BYTE		AUX_STS;				// 0x0C Auxiliary Status
	BYTE		AUX_CTL;				// 0x0D Auxiliary Control
	BYTE		SMLINK_PIN_CTL;			// 0x0E SMLink Pin Control
	BYTE		SMBus_PIN_CTL;			// 0x0F SMBus Pin Control
	BYTE		SLV_STS;				// 0x10 Slave Status
	BYTE		SLV_CMD;				// 0x11 Slave Command
	BYTE		Res1[2];				// 0x12-0x13 Reserved
	BYTE		NOTIFY_DADDR;			// 0x14 Notify Device Address
	BYTE		Res2;					// 0x15 Reserved
	BYTE		NOTIFY_DLOW;			// 0x16 Notify Data Low Byte
	BYTE		NOTIFY_DHIGH;			// 0x17 Notify Data High Byte
} SMBUS_REG, *PSMBUS_REG;

// Adrese rezervate ale dispozitivelor SMBus
#define GENERAL_CALL_ADDR	0x00		// General Call Address (I2C)
#define START_BYTE			0x01		// START Byte (I2C)
#define CBUS_ADDR			0x02		// CBUS Address (I2C)
#define SMBUS_HOST			0x10		// SMBus Host
#define BATTERY_CHARGER		0x12		// Smart Battery Charger
#define BATTERY_SELECTOR	0x14		// Smart Battery Selector
#define SMART_BATTERY		0x16		// Smart Battery
#define ALERT_RESP_ADDR		0x18		// SMBus Alert Response Address
#define PMB_ZONE_READ		0x51		// PMBus Zone Read
#define PMB_ZONE_WRITE		0x6E		// PMBus Zone Write
#define PROTOTYPE_ADDR		0x90		// Prototype Addresses (1001 0XXX)
#define DEV_DEF_ADDR		0xC2		// SMBus Device Default Address
#define TEN_BIT_SLAVE_ADDR	0xF0		// 10-Bit Slave Addressing (1111 0XXX)

#endif
